==> office-ui-fabric-vue-7.0.19.tgz: package/lib/components/Button/IconButton/IconButton.styles.js <==
import { memoizeFunction } from '@uifabric-vue/utilities';
import { HighContrastSelector } from '@uifabric/styling';
import { concatStyleSets } from '@uifabric/merge-styles';
import { getStyles as getStyles$1 } from '../BaseButton.styles.js';

const getStyles = memoizeFunction((theme, customStyles) => {
  const baseButtonStyles = getStyles$1(theme);
  const splitButtonStyles = {}; // getSplitButtonStyles(theme)

  const {
    palette,
    semanticColors
  } = theme;
  const iconButtonStyles = {
    root: {
      padding: '0 4px',
      width: '32px',
      height: '32px',
      backgroundColor: 'transparent',
      border: 'none',
      color: semanticColors.link
    },
    rootHovered: {
      color: palette.themeDarkAlt,
      backgroundColor: palette.neutralLighter,
      selectors: {
        [HighContrastSelector]: {
          borderColor: 'Highlight',
          color: 'Highlight'
        }
      }
    },
    rootHasMenu: {
      width: 'auto'
    },
    rootPressed: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootExpanded: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootChecked: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootCheckedHovered: {
      color: palette.themeDark,
      backgroundColor: palette.neutralQuaternaryAlt
    },
    rootDisabled: {
      color: palette.neutralTertiaryAlt
    }
  };
  return concatStyleSets(baseButtonStyles, iconButtonStyles, splitButtonStyles, customStyles);
});

export { getStyles };

==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Button/IconButton/IconButton.styles.js <==
import { memoizeFunction } from '@uifabric-vue/utilities';
import { HighContrastSelector } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { concatStyleSets } from '@uifabric/merge-styles';
import { getStyles as getStyles$1 } from '../BaseButton.styles.js';
import '../../node_modules/core-js/modules/es.string.link.js';

var getStyles = memoizeFunction(function (theme, customStyles) {
  var baseButtonStyles = getStyles$1(theme);
  var splitButtonStyles = {};
  var palette = theme.palette,
      semanticColors = theme.semanticColors;
  var iconButtonStyles = {
    root: {
      padding: '0 4px',
      width: '32px',
      height: '32px',
      backgroundColor: 'transparent',
      border: 'none',
      color: semanticColors.link
    },
    rootHovered: {
      color: palette.themeDarkAlt,
      backgroundColor: palette.neutralLighter,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderColor: 'Highlight',
        color: 'Highlight'
      })
    },
    rootHasMenu: {
      width: 'auto'
    },
    rootPressed: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootExpanded: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootChecked: {
      color: palette.themeDark,
      backgroundColor: palette.neutralLight
    },
    rootCheckedHovered: {
      color: palette.themeDark,
      backgroundColor: palette.neutralQuaternaryAlt
    },
    rootDisabled: {
      color: palette.neutralTertiaryAlt
    }
  };
  return concatStyleSets(baseButtonStyles, iconButtonStyles, splitButtonStyles, customStyles);
});

export { getStyles };
